@@ -1,8 +1,8 @@
 import datetime as dt
-
+from .connect import Connection
 
 class GoogleCalendar:
-    def __init__(self, auth, cal_id=None):
+    def __init__(self, auth = Connection().cal(), cal_id=None):
         self.service = auth
         self.__all_calendars()
         if cal_id is None:
@@ -10,7 +10,7 @@ class GoogleCalendar:
         else:
             self.calId = cal_id
 
-    def __all_calendars(self):
+    def __all_calendars(self) -> None:
         """
         sets the self.cal_list variable to all the calendars
         that this authentication of google has access to
@@ -19,7 +19,7 @@ class GoogleCalendar:
         """
         self.cal_list = self.service.calendarList().list().execute()
 
-    def _print_ids(self, data=None):
+    def _print_ids(self, data=None) -> None:
         """
         prints the ids of a calendar event, or calendar list
         defaults to printing the calendar list
@@ -34,7 +34,7 @@ class GoogleCalendar:
             except ValueError:
                 print("Error with {}".format(x))
 
-    def set_default(self, calId=None):
+    def set_default(self, calId=None) -> None:
         """
         allows you to set a default calendar for this class
 
@@ -44,13 +44,13 @@ class GoogleCalendar:
         self._print_ids()
         self.calId = input("\nType ID of calendar: ")
 
-    def find_event(self, name):
+    def find_event(self, name) -> dict:
         """
         returns an event by event name
         """
         return self.service.events().list(calendarId=self.calId, q=name).execute()
 
-    def get_event(self, event_id):
+    def get_event(self, event_id) -> dict:
         """
         returns an event by event id
         """
@@ -78,7 +78,7 @@ class GoogleCalendar:
             .execute()
         )
 
-    def update_event(self, new_event, send_update="all"):
+    def update_event(self, new_event, send_update="all") -> dict:
         """
         accepts the updated dictionary object
 
