@@ -4,7 +4,7 @@ https://developers.google.com/analytics/
 devguides/reporting/core/v4/rest/v4/reports/batchGet
 """
 import pandas as pd
-from googlewrapper.connect import Connection
+from .connect import Connection
 
 class GoogleAnalytics:
     def __init__(self, view, auth = Connection().ga(), default_view="df"):
@@ -25,11 +25,11 @@ class GoogleAnalytics:
         self._metric_filter = None
         self._metric_filter_grouping = "OR"
 
-    def set_view(self, view):
+    def set_view(self, view) -> None:
 
         self.viewId = view
 
-    def set_metrics(self, m):
+    def set_metrics(self, m) -> None:
         """
         Parameters
 
@@ -41,7 +41,7 @@ class GoogleAnalytics:
         """
         self._metrics = m
 
-    def set_dimensions(self, d):
+    def set_dimensions(self, d) -> None:
         """
         Parameters
 
@@ -60,12 +60,12 @@ class GoogleAnalytics:
         """
         self._dims = d
 
-    def set_dimension_filters(self, f):
+    def set_dimension_filters(self, f) -> None:
         """
         Parameters
         f: all the dimension filters
           type: list of tupes
-        tuple structure = (dimension name, "not", operator, expression, caseSensitive)
+        tuple structure = (dimension name, 'not', operator, expression, caseSensitive)
 
         dimensionName: dimension to be filtered
           type: str
@@ -130,7 +130,7 @@ class GoogleAnalytics:
         """
         self._metric_filter_grouping = enum
 
-    def set_start_date(self, d):
+    def set_start_date(self, d) -> None:
         """
         Parameters
 
@@ -139,7 +139,7 @@ class GoogleAnalytics:
         """
         self._s_date = d
 
-    def set_end_date(self, d):
+    def set_end_date(self, d) -> None:
         """
         Parameters
 
@@ -261,7 +261,7 @@ class GoogleAnalytics:
         else:
             return self.raw_data
 
-    def create_df(self):
+    def create_df(self) -> pd.DataFrame:
         """
         Loops through the Google Analytics batchGet()
         response json to create a pd.DataFrame
@@ -292,6 +292,7 @@ class GoogleAnalytics:
                         metric_df[col_name] = metric_df[col_name].astype(int)
 
             dim_df = pd.DataFrame([d["dimensions"] for d in row_data], columns=dims)
+            # format dfs for simple merge
             metric_df.index.name = "idx"
             dim_df.index.name = "idx"
             df = dim_df.merge(metric_df, on="idx")
