@@ -1,11 +1,16 @@
 import datetime as dt
 import pandas as pd
-from googlewrapper.connect import Connection
+# nan is used in the "check_branded" method
+# probably can be removed, we just need to check 
+# if a list is empty, I'm sure there is a better way
 from numpy import nan
 import warnings
 
+from .connect import Connection
+
 class GoogleSearchConsole:
     def __init__(self, auth = Connection().gsc()):
+        
         self.auth = auth
 
         # default values for dims and date values
@@ -16,7 +21,7 @@ class GoogleSearchConsole:
         # Variables Assigned throughout the class
 
         # assigned using .set_sites()
-        self._site_list = None
+        self._site_list = self.all_sites()
         # assigned using .set_branded()
         self._branded_dict = None
         # assigned using .set_filters()
@@ -27,7 +32,7 @@ class GoogleSearchConsole:
         # assigned in .ctr() 
         self.my_ctr = None
 
-    def set_sites(self, site_list:list):
+    def set_sites(self, site_list:list) -> None:
         """
         site_list: list of sites we want to pull from GSC API
             type: list
@@ -37,7 +42,7 @@ class GoogleSearchConsole:
         self._site_list = site_list
 
 
-    def set_dimensions(self, dimensions:list):
+    def set_dimensions(self, dimensions:list) -> None:
         """
         d: what we want to break it down by
             type: list
@@ -46,7 +51,7 @@ class GoogleSearchConsole:
         self._dims = dimensions
 
 
-    def set_filters(self, filter_object:list):
+    def set_filters(self, filter_object:list) -> None:
         """
         filters_list: list of filters formated as GSC requires
         example_filter = {
@@ -63,7 +68,7 @@ class GoogleSearchConsole:
         self._filter = filter_object
 
 
-    def set_date(self,date:dt.date):
+    def set_date(self,date:dt.date) -> None:
         """
         date: calls the start and end date as the same day
         """
@@ -71,7 +76,7 @@ class GoogleSearchConsole:
         self._e_date = date
 
 
-    def set_start_date(self, start_date:dt.date):
+    def set_start_date(self, start_date:dt.date) -> None:
         """
         start_date: the starting point (inclusive) 
                         for the API pull
@@ -82,7 +87,7 @@ class GoogleSearchConsole:
         self._s_date = start_date
 
 
-    def set_end_date(self, end_date:dt.date):
+    def set_end_date(self, end_date:dt.date) -> None:
         """
         end_date: the ending point (inclusive) 
                     for the API pull
@@ -93,7 +98,7 @@ class GoogleSearchConsole:
         self._e_date = end_date
 
 
-    def set_branded(self, branded_dictionary:dict):
+    def set_branded(self, branded_dictionary:dict) -> None:
         """
         pass in a dictionary object
 
@@ -103,7 +108,7 @@ class GoogleSearchConsole:
         self._branded_dict = branded_dictionary
 
 
-    def all_sites(self, site_filters=None):
+    def all_sites(self, site_filters=None) -> list:
         """
         return a list of all verfied sites that you have in GSC.
         
@@ -124,7 +129,7 @@ class GoogleSearchConsole:
             return [s for s in clean_list if any(xs in s for xs in site_filters)]
 
 
-    def build_request(self, agg_type="auto", limit=25000, start_row=0, pull=True):
+    def build_request(self, agg_type="auto", limit=25000, start_row=0, pull=True) -> dict:
         """
         https://developers.google.com/webmaster-tools/
         search-console-api-original/v3/searchanalytics/query
@@ -137,6 +142,8 @@ class GoogleSearchConsole:
             defaults 0
         pull: if we want to call the api and pull data
             defaults True
+            pull is used for debugging and should be removed
+            once finalized
         """
 
         request_data = {
@@ -154,7 +161,7 @@ class GoogleSearchConsole:
             return request_data
 
 
-    def execute_request(self, request):
+    def execute_request(self, request:dict) -> dict:
         """
         Executes a searchAnalytics.query request.
 
@@ -170,7 +177,7 @@ class GoogleSearchConsole:
         )
 
 
-    def clean_resp(self, data):
+    def clean_resp(self, data:dict) -> pd.DataFrame:
         """
         Takes raw response, and cleans the data into a pd.Dataframe
         """
@@ -195,7 +202,7 @@ class GoogleSearchConsole:
         return df
 
 
-    def check_branded(self, query_list):
+    def check_branded(self, query_list:list) -> pd.Series:
         """
         Takes in a list of queries.
 
@@ -231,16 +238,18 @@ class GoogleSearchConsole:
             start = 0
             row_limit = 25000
             temp_df = pd.DataFrame()
+            # loop through the api grabbing the maximum rows possible
             while True:
-                try:
-                    temp_df = temp_df.append(
-                        self.clean_resp(
-                            self.build_request(limit=row_limit, start_row=start)
-                        )
-                    )
-                except:
+                # get the data from the api
+                response = self.build_request(limit=row_limit, start_row=start)
+                # if rows is in keys, we have data
+                if 'rows' in response.keys():
+                    df = self.clean_resp(response)
+                    temp_df = temp_df.append(df)
+                    start += row_limit
+                # if not, we have pulled the max, we need to break
+                else:
                     break
-                start += row_limit
 
             data[x] = temp_df
 
